@@ -4,7 +4,7 @@ from django.db import models
 from django.db.models.fields import FieldDoesNotExist
 from django.db.models.fields.related import ForeignKey, ManyToManyField
 from django.conf import settings
-from django.utils.importlib import import_module
+
 from inplaceeditform.adaptors import ADAPTOR_INPLACEEDIT as DEFAULT_ADAPTOR_INPLACEEDIT
 
 has_transmeta = False
@@ -20,11 +20,15 @@ def get_dict_from_obj(obj):
     obj_dict = obj.__dict__
     obj_dict_result = obj_dict.copy()
     for key, value in obj_dict.items():
-        if '_id' in key:
+        if key.endswith('_id'):
             key2 = key.replace('_id', '')
-            obj_dict_result[key2] = obj_dict_result[key]
-            del obj_dict_result[key]
-
+            try:
+                field, model, direct, m2m = obj._meta.get_field_by_name(key2)
+                if isinstance(field, ForeignKey):
+                    obj_dict_result[key2] = obj_dict_result[key]
+                    del obj_dict_result[key]
+            except FieldDoesNotExist:
+                pass
     manytomany_list = obj._meta.many_to_many
     for manytomany in manytomany_list:
         ids = [obj_rel.id for obj_rel in manytomany.value_from_object(obj)]
@@ -45,6 +49,15 @@ def apply_filters(value, filters, load_tags=None):
     return value
 
 
+def import_module(name, package=None):
+    try:
+        from django.utils.importlib import import_module
+        return import_module(name, package)
+    except ImportError:
+        path = [m for m in name.split('.')]
+        return __import__(name, {}, {}, path[-1])
+
+
 def get_adaptor_class(adaptor=None, obj=None, field_name=None):
     if not adaptor:
         try:
@@ -76,7 +89,9 @@ def get_adaptor_class(adaptor=None, obj=None, field_name=None):
     path_adaptor = adaptor and ((getattr(settings, 'ADAPTOR_INPLACEEDIT', None) and
                                  settings.ADAPTOR_INPLACEEDIT.get(adaptor, None)) or
                                  (DEFAULT_ADAPTOR_INPLACEEDIT.get(adaptor, None)))
-    if not path_adaptor:
+    if not path_adaptor and adaptor:
+        return get_adaptor_class(obj=obj, field_name=field_name)
+    elif not path_adaptor:
         return BaseAdaptorField
     path_module, class_adaptor = ('.'.join(path_adaptor.split('.')[:-1]), path_adaptor.split('.')[-1])
     return getattr(import_module(path_module), class_adaptor)
